import kaybee.plugins.articles.article
import kaybee.plugins.articles.featuretiles
import kaybee.plugins.articles.handlers
import kaybee.plugins.articles.homepage
import kaybee.plugins.articles.querylist
import kaybee.plugins.articles.category
import kaybee.plugins.articles.section
import kaybee.plugins.articles.sectionquery
import kaybee.plugins.articles.sectionbox
import kaybee.plugins.articles.toctree
import kaybee.plugins.articles.videoplayer
import kaybee.plugins.debugdumper.handlers
import kaybee.plugins.genericpage.handlers
import kaybee.plugins.localtemplates.handlers
import kaybee.plugins.queries.handlers
import kaybee.plugins.references.handlers
import kaybee.plugins.references.reference
import kaybee.plugins.resources.handlers
import kaybee.plugins.resources.resource
import kaybee.plugins.settings.handlers
import kaybee.plugins.sphinx_app.handlers
import kaybee.plugins.widgets.handlers
import kaybee.plugins.widgets.widget
